===========================
 Invenio-Migrator v1.0.0a9
===========================

Invenio-Migrator v1.0.0a9 was released on July 7, 2017.

About
-----

Utilities for migrating past Invenio versions to Invenio 3.0.

*This is an experimental developer preview release.*

What's new
----------

- Initial public release.

Installation
------------

   $ pip install invenio-migrator==1.0.0a9

Documentation
-------------

   http://invenio-migrator.readthedocs.io/

Happy hacking and thanks for flying Invenio-Migrator.

| Invenio Development Team
|   Email: info@inveniosoftware.org
|   IRC: #invenio on irc.freenode.net
|   Twitter: http://twitter.com/inveniosoftware
|   GitHub: https://github.com/inveniosoftware/invenio-migrator
|   URL: http://inveniosoftware.org
